from regret._api import _DEPRECATOR, Deprecator  # noqa: F401

callable = _DEPRECATOR.callable
inheritance = _DEPRECATOR.inheritance
parameter = _DEPRECATOR.parameter
optional_parameter = _DEPRECATOR.optional_parameter
